<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="utf-8" />
    <title>Chart.js </title>

    <!-- import plugin script -->
    <!-- <script src="https://cdnjs.cloudflare.com/ajax/libs/Chart.js/1.0.1/Chart.js"></script> -->
    <script src="./static/chart.min.js"></script>
</head>

<body>
    {% block content %}{% endblock content %}
</body>

</html>