{% extends "base.html" -%}
{% block content -%}
<h1>Flask Chart.js</h1>
{% include "partials/barchart.html" %}
{% include "partials/linechart.html" %}
{% include "partials/piechart.html" %}
{%- endblock content %}